@@ -31,8 +31,8 @@ from cli.core import Worker
 
 # framework stuff
 from not_so_tuf import Client
-from not_so_tuf.compat import print_function, urllib2
-from not_so_tuf.utils import FROZEN, cwd_, ChDir
+from not_so_tuf.compat import print_, urllib2
+from not_so_tuf.utils import ChDir, cwd_, FROZEN
 from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
@@ -40,6 +40,7 @@ log = logging.getLogger(__name__)
 
 class ClientConfig(object):
 
+    APP_DATA_DIR = '/Users/johny/Library/Caches/nst-cli'
     UPDATE_URL = 'https://s3-us-west-1.amazonaws.com/not-so-tuf/'
     PUBLIC_KEY = (20108396243319911582598596115745239989885400175227707389521317729033635840299100098853596321405101734772502480347809316412443410341343456658819303295609568503560590213458417406289673047067061470663007934259038584291430372736269382548148746125115340848958555445285186466072484498307728141378225246810783728748418077590393647140601680370572187285974144350446751248280469500607629543851685059723717251232927793777304500418725557133877789415933828850137864470404672129358052555306788192180685116519389020808027326496485426387958512948345437474857267466312681047488723469520344767349264331943557545878009395265009303779143L, 65537L)
 
@@ -92,7 +93,7 @@ def main():
     try:
         if FROZEN:
             client = Client(ClientConfig())
-            print('Current Version {}'.format(__version__))
+            print_('Current Version {}'.format(__version__))
             update_check = client.update_check('Not So TUF', __version__)
 
             # Downloading Update
@@ -111,5 +112,5 @@ def main():
             sys.stdout.write('\n\nExited by user\n')
             sys.stdout.flush()
     except Exception as e:
-        print(str(e))
+        print_(str(e))
         log.error(str(e), exc_info=True)
