@@ -31,8 +31,9 @@ from not_so_tuf.compat import urllib2, execute_permission
 from not_so_tuf.config import Config
 from not_so_tuf.downloader import FileDownloader
 from not_so_tuf.patcher import Patcher
-from not_so_tuf.utils import (ChDir, rsa_verify, _version_string_to_tuple,
-                              platform_, FROZEN)
+from not_so_tuf.utils import (ChDir, FROZEN, platform_, rsa_verify,
+                              _version_string_to_tuple)
+
 from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
@@ -85,15 +86,7 @@ class Client(object):
         self.highest_version = None
         self.updates_key = None
 
-        # If data_dir is None
-        #   - windows: we will set it for the users home folder
-        #   - unix: we will set it hidden in the users home folder
-        if self.data_dir is None:
-            extra = '.'
-            if sys.platform == 'win32':
-                extra = ''
-            self.data_dir = os.path.join(os.path.expanduser('~'),
-                                         extra + self.app_name)
+        self.data_dir = _update_data_dir(self.data_dir, self.app_name)
 
         # Has to stay down below since we have to figure out
         # data_dir stuff before we set this.
@@ -502,3 +495,26 @@ start {} "{}" """.format(updated_app, current_app, fix, current_app))
         if not url.endswith('/'):
             return url + '/'
         return url
+
+
+# ToDo: Remove v1.0. Used to transition to
+# new app data dir
+def _update_data_dir(data_dir, app_name):
+    extra = '.'
+    if sys.platform == 'win32':
+        extra = ''
+    old_dir = os.path.join(os.path.expanduser('~'),
+                           extra + app_name)
+
+    if data_dir is None:
+        log.error('Missing updated data dir')
+        log.debug('App data dir: {}'.format(old_dir))
+        return old_dir
+
+    if not os.path.exists(old_dir):
+        log.debug('No need to update app_data_dir')
+    elif not os.path.exists(data_dir):
+        shutil.copytree(old_dir, data_dir)
+
+    log.debug('App data dir: {}'.format(data_dir))
+    return data_dir
