@@ -28,9 +28,10 @@ import os
 import sys
 import time
 
-from cryptography.hazmat.backends import openssl
 from cryptography.fernet import Fernet
+from cryptography.hazmat.backends import openssl
 
+from not_so_tuf.compat import input_
 from not_so_tuf.exceptions import FileCryptError
 
 
@@ -50,13 +51,13 @@ class FileCrypt(object):
         filename (str): The name of the file to encrypt
 
         password_timeout (int): The number of seconds before
-        needing to reenter password. DEFAULT is 30.
+        needing to re-enter password. DEFAULT is 30.
 
         max_tries (int): The number of password attempts before
-        program exists.  DEFAULT is 2
+        program exists.  DEFAULT is 3
     """
 
-    def __init__(self, filename=None, password_timeout=30, max_tries=2):
+    def __init__(self, filename=None, password_timeout=30, max_tries=3):
         self.password = None
         self.password_timer = 0
         self.password_max_tries = max_tries
@@ -116,7 +117,8 @@ class FileCrypt(object):
                                  expected=True)
 
         if not os.path.exists(self.enc_filename):
-            raise FileCryptError('No encrypted file to decrypt')
+            log.error('No file to decrypt')
+            raise FileCryptError('No file to decrypt')
 
         with open(self.enc_filename, 'r') as f:
             log.debug('Grabbing ciphertext.')
@@ -135,7 +137,7 @@ class FileCrypt(object):
                 break
             except Exception as e:
                 self.password = None
-                raw_input('\nInvalid Password.  Press enter to try again')
+                input_('\nInvalid Password.  Press enter to try again')
                 log.warning('Invalid Password')
                 log.error(str(e), exc_info=True)
                 tries += 1
