@@ -33,12 +33,14 @@ try:
 except ImportError:
     bsdiff4 = None
 
+from not_so_tuf.compat import input_, print_
 from not_so_tuf.exceptions import PackageHandlerError
-from not_so_tuf.utils import (ChDir, ask_yes_no, _get_package_hashes,
+from not_so_tuf.utils import (ChDir, FROZEN,
+                              _get_package_hashes,
                               _remove_hidden_stuff_mac,
                               _version_string_to_tuple,
                               _version_tuple_to_string,
-                              FROZEN)
+                              )
 
 log = logging.getLogger(__name__)
 
@@ -170,6 +172,7 @@ class PackageHandler(object):
                 if self._package_plat_version_check(p) is False or \
                     os.path.splitext(p)[1].lower() not in \
                         self.supported_extensions:
+                    log.debug('Bad Package: {}'.format(p))
                     bad_packages.append(p)
                     continue
                 self._update_file_list(p)
@@ -213,9 +216,9 @@ class PackageHandler(object):
                         s['patch_hash'] = _get_package_hashes(i[1])
                         break
         if ignore_errors is False:
-            print 'Bad package names'
+            print_('Bad package names')
             for b in bad_packages:
-                print b
+                print_(b)
 
     def _setup_file_dirs(self):
         # Creates a director with update name
@@ -320,10 +323,11 @@ class PackageHandler(object):
                                                     self.deploy_dir))
 
                 if os.path.exists(os.path.join(version_path, p['real_name'])):
-                    msg = ('Version {} of {} already exists. '
-                           'Overwrite?'.format(p['version'], p['name']))
-                    answer = ask_yes_no(msg)
-                    if answer:
+                    msg = ('Version {} of {} already exists.  Overwrite?\n'
+                           '[N/y]-->'.format(p['version'], p['name']))
+
+                    answer = input_(msg)
+                    if answer.lower() in ['yes', 'ye', 'y']:
                         shutil.rmtree(version_path, ignore_errors=True)
                         os.mkdir(version_path)
                         shutil.move(p['real_name'], version_path)
@@ -359,13 +363,13 @@ class PackageHandler(object):
             self.json_data['latest'][package_name] = {}
 
     def _package_plat_version_check(self, package):
-        found = re.findall('-[macnixw64]{3,5}-[0-9]+\.[0-9]+\.[0-9]', package)
+        found = re.findall('-[macnixwr64]{3,5}-[0-9]+\.[0-9]+\.[0-9]', package)
         if len(found) < 1:
             return False
         return True
 
     def _get_platform(self, name):
-        platform_name = re.compile('[macnixw64]{3,5}').findall(name)[0]
+        platform_name = re.compile('[macnixwr64]{3,5}').findall(name)[0]
         log.debug('Platform name is: {}'.format(platform_name))
         return platform_name
 
@@ -442,10 +446,10 @@ def _make_patch(patch_info):
         patch_number = patch_info['patch_num']
         src_path = patch_info['src']
         dst_path = patch_info['dst']
-        print("Patch name: {}".format(patch_name))
-        print('Patch number: {}'.format(patch_number))
-        print('Src: {}'.format(src_path))
-        print('Dst: {}'.format(dst_path))
+        print_("Patch name: {}".format(patch_name))
+        print_('Patch number: {}'.format(patch_number))
+        print_('Src: {}'.format(src_path))
+        print_('Dst: {}'.format(dst_path))
 
         patch_name += '-' + str(patch_number)
         log.info('Creating patch')
