@@ -32,9 +32,11 @@ except ImportError:
 
 from not_so_tuf.compat import BytesIO
 from not_so_tuf.downloader import FileDownloader
-from not_so_tuf.utils import (ChDir, _get_package_hashes,
+from not_so_tuf.utils import (ChDir, platform_,
+                              _get_package_hashes,
                               _version_string_to_tuple,
-                              _version_tuple_to_string, platform_)
+                              _version_tuple_to_string
+                              )
 
 
 log = logging.getLogger(__name__)
